@@ -16,7 +16,7 @@ class ReceiveBufferFullMessage(velbus.Message):
         """
         @return: None
         """
-        self.needs_low_priority(priority)
+        self.needs_high_priority(priority)
         self.needs_no_rtr(rtr)
         self.needs_no_data(data)
         self.set_attributes(priority, address, rtr)
